@@ -7,6 +7,7 @@ from snappi_ixnetwork.validation import Validation
 from snappi_ixnetwork.vport import Vport
 from snappi_ixnetwork.ngpf import Ngpf
 from snappi_ixnetwork.trafficitem import TrafficItem
+from snappi_ixnetwork.capture import Capture
 from snappi_ixnetwork.timer import Timer
 
 
@@ -51,6 +52,7 @@ class Api(snappi.Api):
         self.vport = Vport(self)
         self.ngpf = Ngpf(self)
         self.traffic_item = TrafficItem(self)
+        self.capture = Capture(self)
 
     def _get_addr_port(self, host):
         items = host.split('/')
@@ -157,7 +159,11 @@ class Api(snappi.Api):
         self._connect()
         return self.traffic_item.transmit(flow_transmit_state)
 
-    def _set_port_capture_state(self, request):
+    def set_link_state(self, link_state):
+        if link_state.port_names is not None:
+            self.vport.set_link_state(link_state)
+    
+    def set_capture_state(self, request):
         """Starts capture on all ports that have capture enabled.
         """
         self._connect()
@@ -187,7 +193,7 @@ class Api(snappi.Api):
             else:
                 self._ixnetwork.StopCapture()
 
-    def get_capture_results(self, request):
+    def get_capture(self, request):
         """Gets capture file and returns it as a byte stream
         """
         with Timer(self, 'Captures stop'):
