@@ -14,7 +14,6 @@ class Vport(object):
     Transformations
     ---------------
     - /components/schemas/Port to /vport
-    - /components/schemas/Capture to /vport/capture
     - /components/schemas/Layer1 to /vport/l1Config/...
 
     Process
@@ -134,16 +133,28 @@ class Vport(object):
         """
         self._resource_manager = self._api._ixnetwork.ResourceManager
         self._ixn_vport = self._api._vport
+        self._layer1_check = []
         with Timer(self._api, 'Ports configuration'):
             self._delete_vports()
             self._create_vports()
         with Timer(self._api, 'Captures configuration'):
-            self._create_capture()
+            self._api.capture.config()
         with Timer(self._api, 'Location configuration'):
             self._set_location()
         with Timer(self._api, 'Layer1 configuration'):
             self._set_layer1()
 
+    def set_link_state(self, link_state):
+        with Timer(self._api, 'Link State operation'):
+            payload = {
+                'arg1': [],
+                'arg2': link_state.state,
+            }
+            for port_name in link_state.port_names:
+                payload['arg1'].append(self._api.get_ixn_href(port_name))
+            url = '%s/vport/operations/linkupdn' % self._api._ixnetwork.href
+            self._api._request('POST', url, payload)
+    
     def _import(self, imports):
         if len(imports) > 0:
             errata = self._resource_manager.ImportConfig(
@@ -181,77 +192,6 @@ class Vport(object):
         for name, vport in self._api.select_vports().items():
             self._api.ixn_objects[name] = vport['href']
 
-    def _create_capture(self):
-        """Overwrite any capture settings
-        """
-        if self._api.snappi_config.captures is None:
-            self._api.snappi_config.captures = []
-        imports = []
-        vports = self._api.select_vports()
-        for vport in vports.values():
-            if vport['capture']['hardwareEnabled'] is True or vport['capture'][
-                    'softwareEnabled'] is True:
-                capture = {
-                    'xpath': vport['capture']['xpath'],
-                    'captureMode': 'captureTriggerMode',
-                    'hardwareEnabled': False,
-                    'softwareEnabled': False
-                }
-                imports.append(capture)
-        for capture_item in self._api.snappi_config.captures:
-            for port_name in capture_item.port_names:
-                capture_mode = 'captureTriggerMode'
-                if capture_item.overwrite:
-                    capture_mode = 'captureContinuousMode'
-                    reset = {'xpath': vports[port_name]['xpath'] + '/capture/trigger'}
-                    reset['captureTriggerEnable'] = False
-                    self._import(reset)
-                isEnable = False
-                if capture_item.enable is True:
-                    isEnable = True
-                capture = {
-                    'xpath': vports[port_name]['xpath'] + '/capture',
-                    'captureMode': capture_mode,
-                    'hardwareEnabled': isEnable,
-                    'softwareEnabled': False
-                }
-                pallette = {'xpath': capture['xpath'] + '/filterPallette'}
-                filter = {'xpath': capture['xpath'] + '/filter'}
-                trigger = {'xpath': capture['xpath'] + '/trigger'}
-                if capture_item.basic is not None and len(
-                        capture_item.basic) > 0:
-                    filter['captureFilterEnable'] = True
-                    trigger['captureTriggerEnable'] = True
-                    filter['captureFilterEnable'] = True
-                    for basic in capture_item.basic:
-                        if basic.choice == 'mac_address' and basic.mac_address.mac == 'source':
-                            pallette['SA1'] = basic.mac_address.filter
-                            pallette['SAMask1'] = basic.mac_address.mask
-                            filter[
-                                'captureFilterSA'] = 'notAddr1' if basic.not_operator is True else 'addr1'
-                            trigger['triggerFilterSA'] = filter[
-                                'captureFilterSA']
-                        elif basic.choice == 'mac_address' and basic.mac_address.mac == 'destination':
-                            pallette['DA1'] = basic.mac_address.filter
-                            pallette['DAMask1'] = basic.mac_address.mask
-                            filter[
-                                'captureFilterDA'] = 'notAddr1' if basic.not_operator is True else 'addr1'
-                            trigger['triggerFilterDA'] = filter[
-                                'captureFilterDA']
-                        elif basic.choice == 'custom':
-                            pallette['pattern1'] = basic.custom.filter
-                            pallette['patternMask1'] = basic.custom.mask
-                            pallette['patternOffset1'] = basic.custom.offset
-                            filter[
-                                'captureFilterPattern'] = 'notPattern1' if basic.not_operator is True else 'pattern1'
-                            trigger['triggerFilterPattern'] = filter[
-                                'captureFilterPattern']
-                imports.append(capture)
-                imports.append(pallette)
-                imports.append(filter)
-                imports.append(trigger)
-        self._import(imports)
-
     def _add_hosts(self, HostReadyTimeout):
         chassis = self._api._ixnetwork.AvailableHardware.Chassis
         add_addresses = []
@@ -288,8 +228,6 @@ class Vport(object):
                     time.sleep(2)
 
     def _get_layer1(self, port):
-        if hasattr(self._api.snappi_config, 'layer1') is False:
-            return
         if len(self._api.snappi_config.layer1) == 0:
             return
         for layer1 in self._api.snappi_config.layer1:
@@ -302,8 +240,8 @@ class Vport(object):
         set it according to the speed"""
 
         resource_group = None
-        location = getattr(port, 'location', None)
-        if location is None or len(location) == 0:
+        location = port.location
+        if len(location) == 0:
             return
         
         (hostname, cardid, portid) = location.split(';')
@@ -318,7 +256,7 @@ class Vport(object):
         if 'aggregation' in card_info.keys() and len(card_info[
                          'aggregation']) > 0:
             for aggregation in card_info['aggregation']:
-                if portid in [res_port.split('/')[-1] for res_port in aggregation[
+                if portid.lstrip('0') in [res_port.split('/')[-1] for res_port in aggregation[
                         'resourcePorts']]:
                     self._reset_resource_mode(card_info, speed_mode_map)
                     resource_group = aggregation
@@ -330,7 +268,7 @@ class Vport(object):
                 mode = speed_mode_map[layer1.speed]
                 for available_mode in resource_group['availableModes']:
                     if re.search(mode, available_mode.lower()) is not None:
-                        layer1.__setattr__('speed_taken_care', True)
+                        self._layer1_check.append(layer1.name)
                         aggregation_mode = available_mode
                         break
             else:
@@ -445,9 +383,7 @@ class Vport(object):
         This should only happen if the vport connectionState is connectedLink...
         as it determines the ./l1Config child node.
         """
-        if hasattr(self._api.snappi_config, 'layer1') is False:
-            return
-        if self._api.snappi_config.layer1 is None:
+        if len(self._api.snappi_config.layer1) == 0:
             return
         reset_auto_negotiation = dict()
         # set and commit the card resource mode
@@ -512,7 +448,7 @@ class Vport(object):
         """
         if vport['connectionState'] not in [
                 'connectedLinkUp', 'connectedLinkDown'
-        ] or hasattr(layer1, 'speed_taken_care'):
+        ] or layer1.name in self._layer1_check:
             return
 
         aggregation_mode = None
@@ -548,7 +484,7 @@ class Vport(object):
         be switched to a type without the Fcoe extension.
         """
         fcoe = False
-        if hasattr(layer1, 'flow_control') and layer1.flow_control is not None:
+        if layer1.flow_control.choice is not None:
             fcoe = True
         vport_type = vport['type']
         elegible_fcoe_vport_types = [
@@ -630,10 +566,10 @@ class Vport(object):
             '{0}'.format(auto_field_name):
             False if layer1.auto_negotiate is None else layer1.auto_negotiate,
             'enableRsFec':
-            False if layer1.auto_negotiation is None else
+            False if layer1.auto_negotiation.rs_fec is None else
             layer1.auto_negotiation.rs_fec,
             'linkTraining':
-            False if layer1.auto_negotiation is None else
+            False if layer1.auto_negotiation.link_training is None else
             layer1.auto_negotiation.link_training,
             'speedAuto':
             advertise
@@ -661,7 +597,7 @@ class Vport(object):
             })
 
     def _set_fcoe(self, vport, layer1, imports):
-        if hasattr(layer1, 'flow_control') and layer1.flow_control is None:
+        if layer1.flow_control.choice is None:
             return
         xpath = '%s/l1Config/%s/fcoe' % (vport['xpath'], vport['type'].replace(
             'Fcoe', ''))
